#ifndef __FIRE_PREFIX_H__
#define __FIRE_PREFIX_H__

#ifndef FIRE_NAMESPACE
#define FIRE_NAMESPACE fire
#endif

#define FIRE_MAJOR_VERSION    1
#define FIRE_INCLUDE_VERSION  1
#define FIRE_MINOR_VERSION    1

#ifndef FIRE_BUILD_NUMBER
#define FIRE_BUILD_NUMBER     1
#endif

#define FIRE_RT_MAJOR_VERSION 2
#define FIRE_RT_INCLUDE_VERSION 5
#define FIRE_RT_MINOR_VERSION 2
#ifndef FIRE_RT_BUILD_NUMBER
#define FIRE_RT_BUILD_NUMBER 0
#endif

#ifdef NDEBUG
#define FIRE_DEBUG_RELEASE "release"
#else
#define FIRE_DEBUG_RELEASE "debug"
#endif

#include <fire/utils/macro.h>

/* Figure out our Operating System (Windows, VMS, Linux, or Solaris) */
#if defined(_WIN32) || defined(__WIN32__) || defined(WIN32)
#define FIRE_MSWIN
#ifndef _CRT_SECURE_NO_WARNINGS
#define _CRT_SECURE_NO_WARNINGS
#endif
#include <fire/private/fire_mswin_prefix.h>
#elif defined (__VMS) || defined (__DECCXX)
#define FIRE_VMS
#include <fire/private/fire_vms_prefix.h>
#elif defined __linux__
#define FIRE_LINUX
#include <fire/private/fire_linux_prefix.h>
#elif defined __sun
#define FIRE_SUNOS
#include <fire/private/fire_sun_prefix.h>
#else
#error "Fire lib does not support this platform"
#endif

/* RTLIB specific */

#define FIRE_RT_VERSION_CHECK    FIRE_STRINGIZE(FIRE_RT_MAJOR_VERSION) "." FIRE_STRINGIZE(FIRE_RT_INCLUDE_VERSION)

#if defined(__cplusplus)
/* Not sure if this is necessary. It isn't used anywhere.

namespace FIRE_NAMESPACE {

// A change in the MAJOR VERSION may require clients to change source code
static const int RT_MAJOR_VERSION   = FIRE_RT_MAJOR_VERSION;

// A change in the INCLUDE VERSION "only" require the clients to recompile
static const int RT_INCLUDE_VERSION = FIRE_RT_INCLUDE_VERSION;

// A change in the MINOR_VERSION only requires the library replacement on
// the runtime systems
static const int RT_MINOR_VERSION = FIRE_RT_MINOR_VERSION;

static const char * const RT_VERSION_LABEL = FIRE_STRINGIZE(FIRE_RT_MAJOR_VERSION) "." FIRE_STRINGIZE(FIRE_RT_INCLUDE_VERSION) "." FIRE_STRINGIZE(FIRE_RT_MINOR_VERSION);

} // namespace
*/

#include <fire/detail/rt_errno.h>

#endif

/* end RTLIB */

/* Define stuff about the cpu architecture we are compiling on */
#include <fire/private/byte_order.h>

/* VMS specific include */
/*#ifdef FIRE_VMS
#include <fire/private/fire_vms_prefix.h>
#endif*/

/*
 * Initialize and cleanup functions.  Clients only need to call these functions
 * when using Windows and linking statically. (i.e. FIRE_LINK_STATIC_LIBRARY is
 * defined).  However, It is safe to call these funcions in any mode on any 
 * system (unix or windows), and multiple times.  Each and every call to
 * fire_initialize() should be paired with a call to fire_cleanup().
 * Initializion will only happen on the first call, and cleanup on the last.
 */
#ifdef __cplusplus
extern "C" {
#endif
extern FIRE_API int fire_initialize();
extern FIRE_API int fire_checked_initialize();
extern FIRE_API int fire_cleanup();
extern FIRE_API int fire_abort_on_err(int err, const char *file, int lineno);
extern FIRE_API const char *fire_label;
#ifdef __cplusplus
}
#endif

#endif
